@@ -9,7 +9,7 @@ use routines;
 
 use Moo;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # BUILD
 
@@ -300,7 +300,7 @@ details.
 
   has data => (
     is => 'ro',
-    crc => fun($arg){'0'}
+    crc => sub {'0'}
   );
 
   package main;
@@ -424,7 +424,7 @@ details.
 
   has data => (
     is => 'ro',
-    def => fun(){time},
+    def => sub {time},
     lzy => 1
   );
 
